//---------------------------------------------------------------------------

#ifndef UaConfH
#define UaConfH
//---------------------------------------------------------------------------

#include <string>
#include <vector>
#include <deque>
#include <assert.h>

class UaConf
{
public:
	struct Account
	{
		enum TRANSPORT_TYPE
		{
			TRANSPORT_UDP = 0,
			TRANSPORT_TCP,
			TRANSPORT_LIMITER
		} transport;
		std::string reg_server;
		std::string user;
		std::string pwd;
		int reg_expires;

		std::string stun_server;

		bool operator==(const Account& right) const {
			return (reg_server == right.reg_server &&
				user == right.user &&
				pwd == right.pwd &&
				transport == right.transport &&
				reg_expires == right.reg_expires &&
				stun_server == right.stun_server
				);
		}
		bool operator!=(const Account& right) const {
			return !(*this == right);
		}
		Account()
		{
			transport = TRANSPORT_UDP;
			reg_expires = 60;
			reg_server = "127.0.0.1:5060";
			user = "3001";
			pwd = "3001";
		}
		const char* const getTransportStr(void) {
			switch (transport)
			{
			case TRANSPORT_UDP:
				return "udp";
			case TRANSPORT_TCP:
				return "tcp";
			default:
				assert(!"Unhandled cfg transport type");
				return "???";
			}
		}
	};
	std::vector<Account> accounts;

	enum { CALL_HISTORY_LIMIT = 20 };
	struct HistoryEntry
	{
		std::string uri;

		bool operator==(const HistoryEntry& right) const {
			return (uri == right.uri);
		}
	};
	std::deque<HistoryEntry> callHistory;

	void AddCallHistoryEntry(HistoryEntry& entry);

	bool logMessages;

	enum SoundBackend {
		PORTAUDIO_DSOUND = 0,
		WINWAVE,
		SOUND_BACKEND_LIMIT
	} soundBackend;

	UaConf() {
		soundBackend = PORTAUDIO_DSOUND;
		logMessages = false;
	}

	bool operator==(const UaConf& right) const {
		if (accounts.size() != right.accounts.size())
			return false;
		for (int i=0; i<accounts.size(); i++)
		{
			if (accounts[i] != right.accounts[i])
			{
				return false;
			}
		}
		if (soundBackend != right.soundBackend)
			return false;
		return true;
	}
	bool operator!=(const UaConf& right) const {
    	return !(*this == right);
	}
};

#endif
